/*************************************************************************/
/*************************************************************************/
/*                                                                       */
/*  File Name : AirFitnessFunction.cc                                    */
/*                                                                       */
/*       Date : May , 1997                                               */
/* Updated at : December 6, 1997                                         */
/*                                                                       */
/*     Author : H. Timucin OZDEMIR                                       */
/*                                                                       */
/*************************************************************************/
/*
  Defines the fitness value of the particular chromosome.
*/
/*************************************************************************/

#include "AirFitnessFunction.h"
#include "AirChromosomes.h"
#include <FitnessFunction.h>
#include <Chromosomes.h>
#include <limits.h>
#include <intFitnessValue.h>
#include <D1FitnessValue.h>
#include <mDFitnessValue.h>

/*************************************************************************/
/*                                                                       */
/*                                                                       */
/*************************************************************************/

AirFitnessFunction::~AirFitnessFunction()
{  //cout << " de allocates AirFitnessFunction " << endl; 
}

/*************************************************************************/
/*
//
// Cost is composed of 
//    1) Cost of all the schedule
//    2) Number of Rotations in the solution
//
*/
/*************************************************************************/

FitnessValue * AirFitnessFunction::apply(Chromosomes *_or)
{  float a[2];

   AirChromosomes * curr = (AirChromosomes *) _or;

   a[0] = (*curr).getCost();
   a[1] = (*curr).getNumOfRotations();

   mDFitnessValue<float> *fv = new mDFitnessValue<float>(2,a);

   (*fv).setFitnessValue(0,a[0]);
   (*fv).setFitnessValue(1,a[1]);
   
   return fv;

}// end of apply()

/*************************************************************************/
/*
//
// Cost is composed of 
//    1) Number of different cities each rotation starts
//    2) Cost of all the schedule
//    3) Number of Rotations in the solution
//
*/
/*************************************************************************/

FitnessValue * AirFitnessFunction::apply1(Chromosomes *_or)
{  float a[3];
   AirChromosomes * curr = (AirChromosomes *) _or;

   a[0] = (*curr).getNumberOfBaseCities();
   a[1] = (*curr).getCost();
   a[2] = (*curr).getNumOfRotations();

   mDFitnessValue<float> *fv = new mDFitnessValue<float>(3,a);
   
   for(unsigned i=0;i<3;i++) (*fv).setFitnessValue(i,a[i]);

   return fv;

}// end of apply()

